.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

============
library.core
============

.. image:: https://travis-ci.com/IMIO/library.core.svg?branch=master
    :target: https://travis-ci.com/IMIO/library.core

.. image:: https://coveralls.io/repos/github/IMIO/library.core/badge.svg?branch=master
    :target: https://coveralls.io/github/IMIO/library.core?branch=master


This product has main source code for bibliotheca instances.


Translations
------------

This product has been translated into

- French


Installation
------------

Install library.core by adding it to your buildout::

    [buildout]

    ...

    eggs =
        library.core


and then running ``bin/buildout``


Contribute
----------

- Source Code: https://github.com/imio/library.core


Support
-------

If you are having issues, please let us know at https://github.com/IMIO/library.core/issues


License
-------

The project is licensed under the GPLv2.
